==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/ab/ab1f2d8237830ac70df61d3ef3024914.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fp-wien/assets/fb-blue.png */
class __TwigTemplate_c49934303db06e8a39d28a98af8d4ad0 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000#\000\000\000b\000\000\000sBIT|d\000\000=IDATHKUQ@^xN\tv@\000+:


br

L\tZxVgnvV):k%NKZҔ/\\dķ?A[\000]K'fw\000ǵY3stgMjw4WKd#0nh~W_6W\tFr]~Y_y,K`!{zt U~!a^}<<gfr[7;f61
)>xtH@`RKFxI
ց>>W(E<&ڎ0p\000VI;NA &׉Q\\WX^X^MqL_.#z\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fp-wien/assets/fb-blue.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fp-wien/assets/fb-blue.png", "/var/www/mautic-ktn/themes/fp-wien/assets/fb-blue.png");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/ab/ab1f2d8237830ac70df61d3ef3024914.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fp-wien/assets/fb-blue.png */
class __TwigTemplate_c49934303db06e8a39d28a98af8d4ad0 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000#\000\000\000b\000\000\000sBIT|d\000\000=IDATHKUQ@^xN\tv@\000+:


br

L\tZxVgnvV):k%NKZҔ/\\dķ?A[\000]K'fw\000ǵY3stgMjw4WKd#0nh~W_6W\tFr]~Y_y,K`!{zt U~!a^}<<gfr[7;f61
)>xtH@`RKFxI
ց>>W(E<&ڎ0p\000VI;NA &׉Q\\WX^X^MqL_.#z\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fp-wien/assets/fb-blue.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fp-wien/assets/fb-blue.png", "/var/www/html/mauticGIT-Test/themes/fp-wien/assets/fb-blue.png");
    }
}
